@@ -1,14 +1,9 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of this
 # repository contains the full copyright notices and license terms.
-
-from unittest import TestCase
-from proteus import config
+from .common import ProteusTestCase
 
 
-class TestContext(TestCase):
-
-    def setUp(self):
-        self.config = config.set_trytond(database_type='sqlite')
+class TestContext(ProteusTestCase):
 
     def test_config(self):
         prev_ctx = self.config._context
